@@ -65,18 +65,17 @@
 //! methods that implement the [complicated semantics] for correctly
 //! locating information.
 //!
-//! [`Cert`]: ../index.html
-//! [`Packet`]: ../../packet/index.html
-//! [`Signature`]: ../../packet/signature/index.html
-//! [`ComponentBundle`]: ./struct.ComponentBundle.html
-//! [`Key`]: ../../packet/key/index.html
-//! [`UserID`]: ../../packet/struct.UserID.html
-//! [`UserAttribute`]: ../../packet/user_attribute/index.html
-//! [`Unknown`]: ../../packet/struct.Unknown.html
-//! [`Tag`]: ../../packet/enum.Tag.html
+//! [`Cert`]: super
+//! [`Packet`]: crate::packet
+//! [`Signature`]: crate::packet::signature
+//! [`Key`]: crate::packet::key
+//! [`UserID`]: crate::packet::UserID
+//! [`UserAttribute`]: crate::packet::user_attribute
+//! [`Unknown`]: crate::packet::Unknown
+//! [`Tag`]: crate::packet::Tag
 //! [designated revoker]: https://tools.ietf.org/html/rfc4880#section-5.2.3.15
-//! [`ComponentAmalgamation`]: ../amalgamation/index.html
-//! [`KeyAmalgamation`]: ../key_amalgamation/index.html
+//! [`ComponentAmalgamation`]: super::amalgamation
+//! [`KeyAmalgamation`]: super::amalgamation::key::KeyAmalgamation
 //! [complicated semantics]: https://tools.ietf.org/html/rfc4880#section-5.2.3.3
 
 use std::time;
@@ -107,7 +106,7 @@ use super::{
 
 /// A certificate component and its associated signatures.
 ///
-/// [See the module level documentation](index.html) for a detailed
+/// [See the module level documentation](self) for a detailed
 /// description.
 #[derive(Debug, Clone, PartialEq)]
 pub struct ComponentBundle<C> {
@@ -136,36 +135,36 @@ assert_send_and_sync!(ComponentBundle<C> where C);
 /// A key (primary or subkey, public or private) and any associated
 /// signatures.
 ///
-/// [See the module level documentation.](index.html)
+/// [See the module level documentation.](self)
 pub type KeyBundle<KeyPart, KeyRole> = ComponentBundle<Key<KeyPart, KeyRole>>;
 
 /// A primary key and any associated signatures.
 ///
-/// [See the module level documentation.](index.html)
+/// [See the module level documentation.](self)
 pub type PrimaryKeyBundle<KeyPart> =
     KeyBundle<KeyPart, key::PrimaryRole>;
 
 /// A subkey and any associated signatures.
 ///
-/// [See the module level documentation.](index.html)
+/// [See the module level documentation.](self)
 pub type SubkeyBundle<KeyPart>
     = KeyBundle<KeyPart, key::SubordinateRole>;
 
 /// A User ID and any associated signatures.
 ///
-/// [See the module level documentation.](index.html)
+/// [See the module level documentation.](self)
 pub type UserIDBundle = ComponentBundle<UserID>;
 
 /// A User Attribute and any associated signatures.
 ///
-/// [See the module level documentation.](index.html)
+/// [See the module level documentation.](self)
 pub type UserAttributeBundle = ComponentBundle<UserAttribute>;
 
 /// An unknown component and any associated signatures.
 ///
 /// Note: all signatures are stored as certifications.
 ///
-/// [See the module level documentation.](index.html)
+/// [See the module level documentation.](self)
 pub type UnknownBundle = ComponentBundle<Unknown>;
 
 
@@ -588,6 +587,7 @@ impl<C> ComponentBundle<C> {
     ///     even if there is a newer self-signature).
     ///
     /// selfsig must be the newest live self signature at time `t`.
+    #[allow(clippy::blocks_in_if_conditions)]
     pub(crate) fn _revocation_status<'a, T>(&'a self, policy: &dyn Policy, t: T,
                                             hard_revocations_are_final: bool,
                                             selfsig: Option<&Signature>)
@@ -614,10 +614,10 @@ impl<C> ComponentBundle<C> {
         let check = |revs: &'a [Signature], sec: HashAlgoSecurity|
             -> Option<Vec<&'a Signature>>
         {
-            let revs = revs.iter().filter_map(|rev| {
+            let revs = revs.iter().filter(|rev| {
                 if let Err(err) = policy.signature(rev, sec) {
                     t!("  revocation rejected by caller policy: {}", err);
-                    None
+                    false
                 } else if hard_revocations_are_final
                     && rev.reason_for_revocation()
                     .map(|(r, _)| {
@@ -633,7 +633,7 @@ impl<C> ComponentBundle<C> {
                        .unwrap_or_else(time_zero),
                        rev.reason_for_revocation()
                        .map(|r| (r.0, String::from_utf8_lossy(r.1))));
-                    Some(rev)
+                    true
                 } else if selfsig_creation_time
                     > rev.signature_creation_time().unwrap_or_else(time_zero)
                 {
@@ -642,7 +642,7 @@ impl<C> ComponentBundle<C> {
                     t!("  newer binding signature trumps soft revocation ({:?} > {:?})",
                        selfsig_creation_time,
                        rev.signature_creation_time().unwrap_or_else(time_zero));
-                    None
+                    false
                 } else if let Err(err)
                     = rev.signature_alive(t, time::Duration::new(0, 0))
                 {
@@ -653,13 +653,13 @@ impl<C> ComponentBundle<C> {
                        rev.signature_validity_period()
                            .unwrap_or_else(|| time::Duration::new(0, 0)),
                        err);
-                    None
+                    false
                 } else {
                     t!("  got a revocation: {:?} ({:?})",
                        rev.signature_creation_time().unwrap_or_else(time_zero),
                        rev.reason_for_revocation()
                            .map(|r| (r.0, String::from_utf8_lossy(r.1))));
-                    Some(rev)
+                    true
                 }
             }).collect::<Vec<&Signature>>();
 
@@ -700,8 +700,8 @@ impl<C> ComponentBundle<C> {
     /// function uses the component's type (`C`) to determine the
     /// packet's type; the type is not a function of whether the key
     /// has secret key material.
-    pub(crate) fn into_packets<'a>(self)
-                                   -> impl Iterator<Item=Packet> + Send + Sync
+    pub(crate) fn into_packets(self)
+                               -> impl Iterator<Item=Packet> + Send + Sync
         where Packet: From<C>
     {
         let p : Packet = self.component.into();
@@ -790,7 +790,7 @@ impl<P: key::KeyParts, R: key::KeyRole> ComponentBundle<Key<P, R>> {
     /// This is just a type-specific alias for
     /// [`ComponentBundle::component`].
     ///
-    /// [`ComponentBundle::component`]: #method.component
+    /// [`ComponentBundle::component`]: ComponentBundle::component()
     ///
     /// # Examples
     ///
@@ -871,7 +871,7 @@ impl ComponentBundle<UserID> {
     /// This is just a type-specific alias for
     /// [`ComponentBundle::component`].
     ///
-    /// [`ComponentBundle::component`]: #method.component
+    /// [`ComponentBundle::component`]: ComponentBundle::component()
     ///
     /// # Examples
     ///
@@ -946,7 +946,7 @@ impl ComponentBundle<UserAttribute> {
     /// This is just a type-specific alias for
     /// [`ComponentBundle::component`].
     ///
-    /// [`ComponentBundle::component`]: #method.component
+    /// [`ComponentBundle::component`]: ComponentBundle::component()
     ///
     /// # Examples
     ///
@@ -1017,7 +1017,7 @@ impl ComponentBundle<Unknown> {
     /// This is just a type-specific alias for
     /// [`ComponentBundle::component`].
     ///
-    /// [`ComponentBundle::component`]: #method.component
+    /// [`ComponentBundle::component`]: ComponentBundle::component()
     ///
     /// # Examples
     ///
